@@ -49,16 +49,16 @@ sub authenticate {
 
     my $remuser;
     if ($self->source eq "REMOTE_USER") {    
-        # compatibility hack:
-        if ($c->engine->can('env') && defined($c->engine->env)) {
-            # BEWARE: $c->engine->env was broken prior 5.80005
-            $remuser = $c->engine->env->{REMOTE_USER};
-        }
-        elsif ($c->req->can('remote_user')) {
+        if ($c->req->can('remote_user')) {
             # $c->req->remote_users was introduced in 5.80005; if not evailable we are
             # gonna use $c->req->user that is deprecated but more or less works as well 
             $remuser = $c->req->remote_user;
         }
+        # compatibility hack:
+        elsif ($c->engine->can('env') && defined($c->engine->env)) {
+            # BEWARE: $c->engine->env was broken prior 5.80005
+            $remuser = $c->engine->env->{REMOTE_USER};
+        }
         elsif ($c->req->can('user')) {
             # maybe show warning that we are gonna use DEPRECATED $req->user            
             if (ref($c->req->user)) {
@@ -77,13 +77,16 @@ sub authenticate {
         # in different variables
         # BEWARE: $c->engine->env was broken prior 5.80005
         my $nam=$self->source;
-        if ($c->engine->can('env')) {
+        if ($c->request->can('env')) {
+            $remuser = $c->request->env->{$nam};
+        }
+        elsif ($c->engine->can('env')) {
             $remuser = $c->engine->env->{$nam};
         }
         else {
             # this happens on Catalyst 5.80004 and before (when using FastCGI)
             Catalyst::Exception->throw( "Cannot handle parameter 'source=$nam'".
-                " as runnig Catalyst engine has broken \$c->engine->env" );
+                " as running Catalyst engine has broken \$c->engine->env" );
         }
     }
     else {
@@ -304,4 +307,61 @@ support $c->req->remote_user.
 This module tries some workarounds when it detects an older version and should
 work as well.
 
+=head1 USING WITH A REVERSE PROXY
+
+If you are using a reverse proxy, then the WEBUSER will not be
+directly accessible by the Catalyst server.  To use remote
+authentication, you will have to modify the web server to set a header
+containing the WEBUSER.  You would then need to modify the PSGI
+configuration to map the header back to the WEBUSER variable.
+
+For example, in Apache you would add the configuration
+
+  RequestHeader unset X-Forwarded-User
+  RewriteEngine On
+  RewriteCond %{LA-U:REMOTE_USER} (.+)
+  RewriteRule . - [E=RU:%1]
+  RequestHeader set X-Forwarded-User %{RU}e
+
+You then need to create a Plack::Middleware module to map the
+header back to the WEBUSER:
+
+  package Plack::Middleware::MyRemote;
+
+  use parent qw( Plack::Middleware );
+
+  use Plack::Util;
+
+  sub call {
+      my ($self, $env) = @_;
+
+      my $user = $env->{HTTP_X_FORWARDED_USER} // "";
+
+      $env->{REMOTE_USER} = $user
+        if ($user && ($user ne '(null)'));
+
+      my $res = $self->app->($env);
+
+      return $res;
+  }
+
+  1;
+
+Finally, you need to modify F<myapp.psgi> to use the custom middleware:
+
+  use strict;
+  use warnings;
+
+  use MyApp;
+
+  use Plack::Builder;
+
+  my $app = Drain->apply_default_middlewares(Drain->psgi_app);
+
+  builder {
+     enable "Plack::Middleware::MyRemote";
+     $app;
+  };
+
+
 =cut
