@@ -5,11 +5,10 @@ use warnings;
 use Catalyst qw/
    Authentication
 /;
+use Moose;
+extends 'Catalyst';
+with 'RemoteTestData';
 
-use base qw/Catalyst/;
-unless ($Catalyst::VERSION >= 5.89000) {
-    __PACKAGE__->engine_class('RemoteTestEngine');
-}
 __PACKAGE__->config(
     'Plugin::Authentication' => {
         default_realm => 'remote',
@@ -31,10 +30,5 @@ __PACKAGE__->config(
     },
 );
 __PACKAGE__->setup;
-if ($Catalyst::VERSION >= 5.89000) {
-    require RemoteTestEngineRole;
-    RemoteTestEngineRole->meta->apply(__PACKAGE__->engine);
-}
 
 1;
-
